.. circfirm documentation master file, created by
   sphinx-quickstart on Thu Mar  7 21:00:53 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Introduction
   :hidden:

   Quickstart <self>

.. toctree::
   :maxdepth: 2
   :caption: Commands:
   :hidden:

   commands/update
   commands/install
   commands/current
   commands/cache
   commands/query
   commands/config

.. toctree::
   :maxdepth: 2
   :caption: Examples
   :hidden:

   examples/update_many
   examples/weekly_cache

.. toctree::
   :maxdepth: 2
   :caption: Infrastructure
   :hidden:

   infrastructure/codecheck
   infrastructure/tests
   infrastructure/docs
   infrastructure/ci
   infrastructure/license
